.. :changelog:

Release History
---------------

dev
+++

0.4.3 (2018-07-25)
+++++++++++++++++++

**Improvements**

- Readme refactored, notebook demos available on binder #23
- Based on nbrmd 0.4.3 (multiline comments now supported)

0.4.0 (2018-07-18)
+++++++++++++++++++

**Improvements**

- lighter, pep8 compliant notebook format
- screenshots in readme

**Bug fixes**

- tests fixed on older python


0.3.0 (2018-07-17)
+++++++++++++++++++

**Improvements**

- nbsrc script that converts Jupyter notebooks to R and python scripts
- src plugin for nbconvert
- Initial documentation (readme)
